@@ -273,6 +273,14 @@ def test_missing_grid_mapping_invalid(test_var_multidim_no_xy):
     assert 'metpy_crs' not in data_var.coords
 
 
+def test_xy_not_vertical(test_ds):
+    """Test not detecting x/y as a vertical coordinate based on metadata."""
+    test_ds.x.attrs['positive'] = 'up'
+    test_ds.y.attrs['positive'] = 'up'
+    data_var = test_ds.metpy.parse_cf('Temperature')
+    assert data_var.metpy.vertical.identical(data_var.coords['isobaric'])
+
+
 def test_missing_grid_mapping_var(caplog):
     """Test behavior when we can't find the variable pointed to by grid_mapping."""
     x = xr.DataArray(np.arange(3),
@@ -407,10 +415,10 @@ def test_resolve_axis_conflict_double_lonlat(test_ds_generic):
     test_ds_generic['d'].attrs['_CoordinateAxisType'] = 'Lat'
     test_ds_generic['e'].attrs['_CoordinateAxisType'] = 'Lon'
 
-    with pytest.warns(UserWarning, match='More than one x coordinate'),\
+    with pytest.warns(UserWarning, match=r'More than one \w+ coordinate'),\
             pytest.raises(AttributeError):
         test_ds_generic['test'].metpy.x
-    with pytest.warns(UserWarning, match='More than one y coordinate'),\
+    with pytest.warns(UserWarning, match=r'More than one \w+ coordinate'),\
             pytest.raises(AttributeError):
         test_ds_generic['test'].metpy.y
 
@@ -422,10 +430,10 @@ def test_resolve_axis_conflict_double_xy(test_ds_generic):
     test_ds_generic['d'].attrs['standard_name'] = 'projection_x_coordinate'
     test_ds_generic['e'].attrs['standard_name'] = 'projection_y_coordinate'
 
-    with pytest.warns(UserWarning, match='More than one x coordinate'),\
+    with pytest.warns(UserWarning, match=r'More than one \w+ coordinate'),\
             pytest.raises(AttributeError):
         test_ds_generic['test'].metpy.x
-    with pytest.warns(UserWarning, match='More than one y coordinate'),\
+    with pytest.warns(UserWarning, match=r'More than one \w+ coordinate'),\
             pytest.raises(AttributeError):
         test_ds_generic['test'].metpy.y
 
